about summary refs log tree commit homepage
path: root/lib/dtas/player/client_handler.rb
diff options
context:
space:
mode:
authorEric Wong <normalperson@yhbt.net>2013-09-09 08:33:05 +0000
committerEric Wong <normalperson@yhbt.net>2013-09-09 08:33:05 +0000
commit385563d1d99fda2735c78884ab135c8b77bc651a (patch)
tree56f0aedea71154e8473c6d4d59cc2e1f5d8e6c19 /lib/dtas/player/client_handler.rb
parent5484099e7cc3077ed2bb5631d0f2f33f6df1e483 (diff)
downloaddtas-385563d1d99fda2735c78884ab135c8b77bc651a.tar.gz
"wall" is analogous to the wall(1) command, so we shall use that
instead of echo.
Diffstat (limited to 'lib/dtas/player/client_handler.rb')
-rw-r--r--lib/dtas/player/client_handler.rb8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/dtas/player/client_handler.rb b/lib/dtas/player/client_handler.rb
index 9697f39..6070851 100644
--- a/lib/dtas/player/client_handler.rb
+++ b/lib/dtas/player/client_handler.rb
@@ -317,7 +317,7 @@ module DTAS::Player::ClientHandler # :nodoc:
 
   def skip_handler(io, msg)
     __current_drop
-    echo("skip")
+    wall("skip")
     io.emit("OK")
   end
 
@@ -334,13 +334,13 @@ module DTAS::Player::ClientHandler # :nodoc:
 
   def do_pause
     return if @paused
-    echo("pause")
+    wall("pause")
     @paused = true
     __current_requeue
   end
 
   def do_play
# no echo, next_source will echo on new track
     @paused = false
     return if @current
     next_source(_next)
@@ -489,7 +489,7 @@ module DTAS::Player::ClientHandler # :nodoc:
     rescue => e
       return io.emit("ERR chdir: #{e.message}")
     end
# echo(%W(cd msg[0])) # should we broadcast this?
     io.emit("OK")
   end
@@ -334,13 +334,13 @@ module DTAS::Player::ClientHandler # :nodoc:
 
   def do_play
-    # no echo, next_source will echo on new track
+    # no wall, next_source will wall on new track
     @paused = false
     return if @current
@@ -489,7 +489,7 @@ module DTAS::Player::ClientHandler # :nodoc:
       return io.emit("ERR chdir: #{e.message}")
     end
-    # echo(%W(cd msg[0])) # should we broadcast this?
+    # wall(%W(cd msg[0])) # should we broadcast this?
     io.emit("OK")
   end